=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2011-03-15 21:30:35 +0000
+++ drizzled/session.cc	2011-03-15 22:08:48 +0000
@@ -74,6 +74,7 @@
 #include <drizzled/sql_lex.h>
 #include <drizzled/ha_data.h>
 #include <drizzled/diagnostics_area.h>
+#include <drizzled/session/state.h>
 
 #include <algorithm>
 #include <climits>
@@ -157,6 +158,7 @@
     the same lex. (@see mysql_parse for details).
   */
   LEX lex;
+  session::TableMessages table_message_cache;
 };
 
 Session::Session(plugin::Client *client_arg, catalog::Instance::shared_ptr catalog_arg) :
@@ -293,6 +295,11 @@
   return lex().sql_command;
 }
 
+session::TableMessages& Session::getMessageCache()
+{
+  return impl_->table_message_cache;
+}
+
 void statement::Statement::set_command(enum_sql_command v)
 {
 	session().lex().sql_command= v;

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2011-03-15 21:40:08 +0000
+++ drizzled/session.h	2011-03-15 22:08:48 +0000
@@ -39,7 +39,6 @@
 #include <drizzled/pthread_globals.h>
 #include <drizzled/query_id.h>
 #include <drizzled/session/property_map.h>
-#include <drizzled/session/state.h>
 #include <drizzled/session/table_messages.h>
 #include <drizzled/session/transactions.h>
 #include <drizzled/sql_error.h>
@@ -76,6 +75,12 @@
 
 namespace internal { struct st_my_thread_var; }
 
+namespace session 
+{ 
+  class State; 
+  class TableMessages;
+}
+
 namespace table 
 { 
   class Placeholder; 
@@ -248,11 +253,11 @@
   }
 
 private:
-  session::State::shared_ptr  _state;
+  boost::shared_ptr<session::State> _state;
 
 public:
 
-  session::State::const_shared_ptr state()
+  const boost::shared_ptr<session::State>& state()
   {
     return _state;
   }
@@ -1420,10 +1425,7 @@
   table::Placeholder *table_cache_insert_placeholder(const identifier::Table &identifier);
   bool lock_table_name_if_not_cached(const identifier::Table &identifier, Table **table);
 
-  session::TableMessages &getMessageCache()
-  {
-    return _table_message_cache;
-  }
+  session::TableMessages &getMessageCache();
 
   /* Reopen operations */
   bool reopen_tables();
@@ -1495,7 +1497,6 @@
     return not getrusage(RUSAGE_THREAD, &usage);
   }
 
-  session::TableMessages _table_message_cache;
   boost::scoped_ptr<impl_c> impl_;
   catalog::Instance::shared_ptr _catalog;
 

=== modified file 'drizzled/session/state.cc'
--- drizzled/session/state.cc	2011-02-17 00:14:13 +0000
+++ drizzled/session/state.cc	2011-03-15 22:08:48 +0000
@@ -22,14 +22,11 @@
 
 #include <drizzled/session/state.h>
 #include <drizzled/definitions.h>
-
+#include <cstring>
 #include <string>
 
-namespace drizzled
-{
-
-namespace session
-{
+namespace drizzled {
+namespace session {
 
 State::State(const char *in_packet, size_t in_packet_length)
 {

=== modified file 'drizzled/session/state.h'
--- drizzled/session/state.h	2011-03-14 05:40:28 +0000
+++ drizzled/session/state.h	2011-03-15 22:08:48 +0000
@@ -20,20 +20,17 @@
 
 #pragma once
 
-#include <drizzled/util/string.h>
-#include <boost/unordered_map.hpp>
+#include <boost/shared_ptr.hpp>
+#include <vector>
 
-namespace drizzled
-{
+namespace drizzled {
 
 class Session;
 
-namespace session
+namespace session {
+
+class State 
 {
-
-class State {
-  std::vector <char> _query;
-
 public:
   typedef boost::shared_ptr<State> shared_ptr;
   typedef boost::shared_ptr<State> const_shared_ptr;
@@ -46,6 +43,8 @@
 
 protected:
   friend class Session;
+private:
+  std::vector<char> _query;
 };
 
 } /* namespace session */

=== modified file 'plugin/session_dictionary/processlist.cc'
--- plugin/session_dictionary/processlist.cc	2011-03-10 11:16:26 +0000
+++ plugin/session_dictionary/processlist.cc	2011-03-15 22:08:48 +0000
@@ -29,7 +29,7 @@
 #include <drizzled/plugin/authorization.h>
 #include <drizzled/internal/my_sys.h>
 #include <drizzled/internal/thread_var.h>
-
+#include <drizzled/session/state.h>
 #include <set>
 
 using namespace std;

=== modified file 'plugin/session_dictionary/sessions.cc'
--- plugin/session_dictionary/sessions.cc	2011-02-23 17:21:37 +0000
+++ plugin/session_dictionary/sessions.cc	2011-03-15 22:08:48 +0000
@@ -30,7 +30,7 @@
 #include <drizzled/plugin/authorization.h>
 #include <drizzled/plugin/client.h>
 #include <drizzled/pthread_globals.h>
-
+#include <drizzled/session/state.h>
 #include <set>
 
 using namespace std;

